// Author:		Dario Accornero <adario@cs.bu.edu>
// BeDev ID:	10183
// Project:		BeScript
// Module:
// Parser for a BeScript source file.

/*
	Copyright 2000, Dario Accornero.   All Rights Reserved.
	This file may be used under the terms of the Modified Be Sample Code License
	(the "Software License" document accompanying this file).
*/

// System headers.

#ifndef __CSTDIO__
#include <cstdio>
#endif

// Local headers.

#include "errormsg.h"
#include "ScriptingUtils.h"
#include "AbstractSyntax.h"
#include "parser.h"

// EXTERNAL IMPORTED DATA AND FUNCTIONS:
// Parsing call and abstract syntax tree.

extern int			yyparse(void);
extern CommandList*	gProgram;

// Parse and optionally display a given file.
// The file is opened and closed in order to let multiple
// files be handled in sequence.

void* parse(const char* fname, bool display) 
{
  // Open file, parse it, and close it immediately.

	EM_open(fname);
	if (display)
		printf("Parsing %s:", fname);
	int parseResult = yyparse();
	
	// If parsing was successful, possibly display the
	// abstract syntax tree before returning it.
	// If parsing wasn't successful, just return NULL.
	
	if (!parseResult)
	{
		if (display)
		{
			printf(" done!\nAbstract syntax for %s:\n", fname);
			gProgram->Print();
		}
		return (void*)gProgram;
	}
	else
	  return 0;
}
